/*
    ---------------------------------------------------------------------- copyright and license ---

    file: src/interceptor-x.hpp

    Copyright © 2014, 2016—2017, 2019 Van de Bugger.

    This file is a part of Tapper.

    Tapper is free software: you can redistribute it and/or modify it under the terms of the GNU
    General Public License as published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Tapper is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
    even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License along with Tapper.  If not,
    see <http://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later

    ---------------------------------------------------------------------- copyright and license ---
*/

#ifndef _INTERCEPTOR_X_HPP_
#define _INTERCEPTOR_X_HPP_

#include "base.hpp"
#include "interceptor.hpp"
#include "x.hpp"    //  XRecordInterceptData

namespace tapper {
namespace interceptor {

// -------------------------------------------------------------------------------------------------
// interceptor::x_t
// -------------------------------------------------------------------------------------------------

class x_t : public object_t, public interceptor_t {

    public :

        explicit x_t();
        virtual ~x_t();

        virtual string_t            type()                       override;
        virtual key_range_t const & key_range()                  override;
        virtual key_names_t const & key_names()                  override;
        virtual key_codes_t const & key_codes()                  override;
        virtual key_t               key( string_t const & name ) override;
        virtual void                start()                      override;
        virtual void                stop()                       override;

    protected :

        virtual string_t _key_name( key_t key ) override;

    private :

        x::kb_t & kb();
        void      on_intercept( XRecordInterceptData const * data );

    private :

        x::record::context_t    _context;
        x::kb_p                 _kb;
        key_range_p             _key_range;
        key_names_p             _key_names;
        key_codes_p             _key_codes;

}; // class x_t

}; // namespace interceptor
}; // namespace tapper

#endif // _INTERCEPTOR_X_HPP_

// end of file //
