/*
    ---------------------------------------------------------------------- copyright and license ---

    file: src/layouter-gnome.cpp

    Copyright © 2014, 2016—2017, 2019 Van de Bugger.

    This file is a part of Tapper.

    Tapper is free software: you can redistribute it and/or modify it under the terms of the GNU
    General Public License as published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Tapper is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
    even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License along with Tapper.  If not,
    see <http://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later

    ---------------------------------------------------------------------- copyright and license ---
*/

#include "layouter-gnome.hpp"

#include <giomm/settings.h>

namespace tapper {
namespace layouter {

// -------------------------------------------------------------------------------------------------
// gnome_t
// -------------------------------------------------------------------------------------------------

gnome_t::gnome_t(
) :
    OBJECT_T(),
    _ism( new gnome::input_source_manager_t )
{
}; // ctor

string_t
gnome_t::type(
) {
    return "GnomeShell";
}; //type

uint_t
gnome_t::layout_max(
) {
    return 255; // TODO: Real number?
};

time_t
gnome_t::get_autorepeat_delay(
) {
    auto _settings = Gio::Settings::create( "org.gnome.desktop.peripherals.keyboard" );
    return _settings->get_uint( "delay" );
};

strings_t
gnome_t::layouts(
) {
    return _ism->keyboard_layouts();
}; // layouts

/**
    Activates specified keyboard layout.
**/
void
gnome_t::activate(
    uint_t layout
) {
    _ism->activate_layout( layout, _bell );
}; // activate

}; // namespace layouter
}; // namespace tapper

// end of file //
