/*
    ---------------------------------------------------------------------- copyright and license ---

    file: src/layouter.hpp

    Copyright © 2014, 2016—2017, 2019 Van de Bugger.

    This file is a part of Tapper.

    Tapper is free software: you can redistribute it and/or modify it under the terms of the GNU
    General Public License as published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Tapper is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
    even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License along with Tapper.  If not,
    see <http://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later

    ---------------------------------------------------------------------- copyright and license ---
*/

#ifndef _LAYOUTER_HPP_
#define _LAYOUTER_HPP_

#include "base.hpp"

namespace tapper {

// -------------------------------------------------------------------------------------------------
// layouter_t
// -------------------------------------------------------------------------------------------------

class layouter_t;
typedef ptr_t< layouter_t > layouter_p;

/**
    Layouter interface.

    "Layouter" is a shorter name of "Layout manager".
**/
class layouter_t {

    public :

        virtual ~layouter_t() = default;

        /**  Returns layouter type name. **/
        virtual string_t type() = 0;

        /** Returns the largest layout number. **/
        virtual uint_t layout_max() = 0;

        virtual time_t get_autorepeat_delay() = 0;

        virtual void set_bell( bool bell );

        /** Returns array of layout names. **/
        virtual strings_t layouts() = 0;

        /** Activates layout specified by number. **/
        virtual void activate( uint_t layout ) = 0;

    protected :

        bool _bell { false };

}; // class layouter_t

}; // namespace tapper

#endif // _LAYOUTER_HPP_

// end of file //
