/*
    ---------------------------------------------------------------------- copyright and license ---

    file: src/ui.cpp

    Copyright © 2014, 2016—2017, 2019 Van de Bugger.

    This file is a part of Tapper.

    Tapper is free software: you can redistribute it and/or modify it under the terms of the GNU
    General Public License as published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Tapper is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
    even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License along with Tapper.  If not,
    see <http://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later

    ---------------------------------------------------------------------- copyright and license ---
*/

/**
    @file
    User interface implementation.
**/

#include "ui.hpp"

#include <iostream>

#include "base.hpp"

namespace tapper {

void oprint( string_t const & message ) {
    std::cout << message << "\n";
};

void eprint( severity_t level, string_t const & message ) {
    string_t prefix = "?";
    switch ( level ) {
        case severity_t::error : {
            prefix = "E";
        } break;
        case severity_t::warning : {
            prefix = "W";
        } break;
        case severity_t::info : {
            prefix = "I";
        } break;
        case severity_t::debug : {
            prefix = "#";
        } break;
    };
    std::cerr << STR( program_invocation_short_name << ": " << prefix << " " << message << "\n" );
}; // eprint

}; // namespace tapper

// end of file //
